@@ -1,5 +1,8 @@
 import numpy as np
-import torch
+try:
+    import torch
+except ImportError:
+    pass
 import warnings
 from pdb import set_trace
 from scipy.optimize import linear_sum_assignment
