@@ -5,14 +5,20 @@ from sklearn.metrics import normalized_mutual_info_score as mi_func
 from pdb import set_trace
 import gc
 import math
-import matplotlib.cm as cm
-import matplotlib.pyplot as plt
+try:
+    import matplotlib.cm as cm
+    import matplotlib.pyplot as plt
+except ImportError:
+    pass
 import numpy as np
 import os
 import sys
-import torch
-from torch.utils import data
-import torch.multiprocessing as mp
+try:
+    import torch
+    from torch.utils import data
+    import torch.multiprocessing as mp
+except ImportError:
+    pass
 from dl_utils.tensor_funcs import numpyify
 
 class CifarLikeDataset(data.Dataset):
