@@ -1,7 +1,13 @@
-import torch
+try:
+    import torch
+except ImportError:
+    pass
 import numpy as np
 import os
-import matplotlib.pyplot as plt
+try:
+    import matplotlib.pyplot as plt
+except ImportError:
+    pass
 
 def to_float_tensor(item): return item.float().div_(255.)
 def add_colour_dimension(item):
